==> react-app-logic-12.1.0.tgz: package/src/gov/providers/ProposalDetailProvider.tsx <==
import React, { createContext, useContext, useMemo } from 'react';
import { useAsyncStatuses } from '@onomy/react-utils';
import { useDetailedBalance, useProposal, useProposalMinDeposit } from '@onomy/react-hub';

import { PlaceholderLoadingIndicator } from '../../components/PlaceholderLoadingIndicator';
import { PlaceholderErrorDisplay } from '../../components/PlaceholderErrorDisplay';
import { calculateVotesChartData } from '../../governanceUtils';

function useProposalDetailState(proposalId: string) {
  const [proposal, proposalStatus] = useProposal(proposalId);

  const votesChartData = useMemo(() => {
    return proposal ? calculateVotesChartData(proposal) : [0, 0, 0];
  }, [proposal]);

  const isVotingPeriod = proposal?.status === 'PROPOSAL_STATUS_VOTING_PERIOD';
  const isDepositPeriod = proposal?.status === 'PROPOSAL_STATUS_DEPOSIT_PERIOD';

  const [minDepositAmount, minDepositAmountStatus] = useProposalMinDeposit();

  // TODO: support multiple deposit denoms?
  const depositNeededFixed =
    minDepositAmount.amount - (proposal?.totalDeposits[0]?.amount ?? BigInt(0));
  const [depositNeeded, depositNeededStatus] = useDetailedBalance(
    minDepositAmount.asset,
    depositNeededFixed.toString(10)
  );

  const loadingStatus = useAsyncStatuses([
    proposalStatus,
    minDepositAmountStatus,
    depositNeededStatus,
  ]);

  return {
    proposalId,

    proposal,
    votesChartData,
    isVotingPeriod,
    isDepositPeriod,
    minDepositAmount,
    depositNeeded,

    loadingStatus,
  };
}

export type ProposalDetailContextType = ReturnType<typeof useProposalDetailState>;

const ProposalDetailContext = createContext<ProposalDetailContextType>(null as any);

export function useProposalDetail() {
  const state = useContext(ProposalDetailContext);
  if (!state) throw new Error('ProposalDetailContext missing');
  return state;
}

// eslint-disable-next-line @typescript-eslint/naming-convention
function DEFAULT_LOADING_RENDER_FN() {
  return <PlaceholderLoadingIndicator text="Loading proposal" />;
}
// eslint-disable-next-line @typescript-eslint/naming-convention
function DEFAULT_ERROR_RENDER_FN(error: any) {
  return <PlaceholderErrorDisplay error={error} />;
}

export function ProposalDetailProvider({
  children,
  getProposalId,
  renderLoading = DEFAULT_LOADING_RENDER_FN,
  renderError = DEFAULT_ERROR_RENDER_FN,
}: {
  children: JSX.Element | JSX.Element[];
  getProposalId: () => string;
  renderLoading?: typeof DEFAULT_LOADING_RENDER_FN;
  renderError?: typeof DEFAULT_ERROR_RENDER_FN;
}) {
  const state = useProposalDetailState(getProposalId());

  if (state.loadingStatus.pending) return renderLoading();
  if (state.loadingStatus.error) return renderError(state.loadingStatus.error);
  if (!state.proposal) return renderLoading();
  return <ProposalDetailContext.Provider value={state}>{children}</ProposalDetailContext.Provider>;
}

==> react-app-logic-15.4.0.tgz: package/src/gov/providers/ProposalDetailProvider.tsx <==
import React, { createContext, useContext, useMemo } from 'react';
import { useAsyncStatuses } from '@onomy/react-utils';
import { useDetailedBalance, useProposal, useProposalMinDeposit } from '@onomy/react-hub';

import { PlaceholderErrorDisplay } from '../../components/PlaceholderErrorDisplay';
import { calculateVotesChartData } from '../../governanceUtils';

function useProposalDetailState(props: Parameters<typeof useProposal>[0]) {
  const [proposal, proposalStatus] = useProposal(props);

  const votesChartData = useMemo(() => {
    return proposal ? calculateVotesChartData(proposal) : [0, 0, 0];
  }, [proposal]);

  const isVotingPeriod = proposal?.status === 'PROPOSAL_STATUS_VOTING_PERIOD';
  const isDepositPeriod = proposal?.status === 'PROPOSAL_STATUS_DEPOSIT_PERIOD';

  const [minDepositAmount, minDepositAmountStatus] = useProposalMinDeposit(props.chain);

  // TODO: support multiple deposit denoms?
  const depositNeededFixed =
    minDepositAmount.amount - (proposal?.totalDeposits[0]?.amount ?? BigInt(0));
  const [depositNeeded, depositNeededStatus] = useDetailedBalance(
    minDepositAmount.asset,
    depositNeededFixed.toString(10)
  );

  const loadingStatus = useAsyncStatuses([
    proposalStatus,
    minDepositAmountStatus,
    depositNeededStatus,
  ]);

  return {
    chain: props.chain,
    proposalId: props.id,

    proposal,
    votesChartData,
    isVotingPeriod,
    isDepositPeriod,
    minDepositAmount,
    depositNeeded,

    loadingStatus,
  };
}

export type ProposalDetailContextType = ReturnType<typeof useProposalDetailState>;

const ProposalDetailContext = createContext<ProposalDetailContextType>(null as any);

export function useProposalDetail() {
  const state = useContext(ProposalDetailContext);
  if (!state) throw new Error('ProposalDetailContext missing');
  return state;
}

function defaultRenderError(error: any) {
  return <PlaceholderErrorDisplay error={error} />;
}

export function ProposalDetailProvider({
  children,
  renderLoading,
  renderError = defaultRenderError,
  ...props
}: {
  children: JSX.Element | JSX.Element[];
  renderLoading?: () => JSX.Element | JSX.Element[] | null;
  renderError?: typeof defaultRenderError;
} & Parameters<typeof useProposalDetailState>[0]) {
  const state = useProposalDetailState(props);

  if (renderLoading && state.loadingStatus.pending) return renderLoading();
  if (state.loadingStatus.error) return renderError(state.loadingStatus.error);
  if (!state.proposal && renderLoading) return renderLoading();
  return <ProposalDetailContext.Provider value={state}>{children}</ProposalDetailContext.Provider>;
}
